@@ -20,6 +20,7 @@ from __future__ import print_function
 from __future__ import unicode_literals
 
 import collections
+import re
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope.concepts import concepts
@@ -55,6 +56,16 @@ _ENTITY_TUPLES = [
 ENTITIES = {item.singular: item for item in _ENTITY_TUPLES}
 
 
+def _ValidPatternForEntity(name):
+  pattern = ENTITIES[name].valid_pattern
+  return r".*" if pattern is None else pattern
+
+
+def ValidPatternForEntity(entity_name):
+  """Returns a compiled regex that matches valid values for `entity_name`."""
+  return re.compile(_ValidPatternForEntity(entity_name))
+
+
 def AttributeConfig(name, fallthroughs=None, help_text=None, validate=False):
   """Returns a ResourceParameterAttributeConfig for the attribute named `name`.
 
@@ -68,9 +79,9 @@ def AttributeConfig(name, fallthroughs=None, help_text=None, validate=False):
       matches the expected pattern.
   """
   validator = None
-  if ENTITIES[name].valid_pattern and validate:
+  if validate:
     validator = arg_parsers.RegexpValidator(
-        ENTITIES[name].valid_pattern,
+        _ValidPatternForEntity(name),
         "Must match the format of a valid {2} ({3})".format(*ENTITIES[name]))
 
   return concepts.ResourceParameterAttributeConfig(
@@ -101,8 +112,11 @@ def ResourceSpec(path, fallthroughs=tuple(), help_texts=None, validate=False):
         fallthrough for fallthrough in fallthroughs
         if entity.singular in fallthrough
     ]
-    config = AttributeConfig(entity.singular, relevant_fallthroughs,
-                             help_texts[entity.singular], validate=validate)
+    config = AttributeConfig(
+        entity.singular,
+        relevant_fallthroughs,
+        help_texts[entity.singular],
+        validate=validate)
     ids[entity.plural + "Id"] = config
 
   return concepts.ResourceSpec(
