@@ -40,6 +40,22 @@ class BuildsCompleter(completers.ListCommandCompleter):
         **kwargs)
 
 
+def AddRegionFlag(parser, hidden=False):
+  """Adds a flag to select a region of the Cloud Build Service.
+
+  Args:
+    parser: The argparse parser to add the arg to.
+    hidden: If true, retain help but do not display it.
+  """
+  parser.add_argument(
+      '--region',
+      hidden=hidden,
+      help='The region of the Cloud Build Service to use.\n'
+      'Must be set to us-central-1.\n'
+      'If unset, the global service is used. The global service is isolated '
+      'from all regional services.')
+
+
 def AddBuildArg(parser, intro=None):
   """Adds a 'build' arg to the given parser.
 
@@ -184,13 +200,52 @@ def AddConfigFlags(parser):
       'instead of a build config file. If you specify a tag in this '
       'command, your source must include a Dockerfile. For instructions '
       'on building using a Dockerfile see '
-      'https://cloud.google.com/cloud-build/docs/quickstart-docker.')
+      'https://cloud.google.com/cloud-build/docs/quickstart-build.')
   build_config.add_argument(
       '--config',
       default='cloudbuild.yaml',  # By default, find this in the current dir
       help='The YAML or JSON file to use as the build configuration file.')
 
 
+def AddConfigFlagsAlpha(parser):
+  """Add config flags."""
+  build_config = parser.add_mutually_exclusive_group()
+  build_config.add_argument(
+      '--tag',
+      '-t',
+      help='The tag to use with a "docker build" image creation. '
+      'Cloud Build will run a remote "docker build -t '
+      '$TAG .", where $TAG is the tag provided by this flag. The tag '
+      'must be in the gcr.io/* or *.gcr.io/* namespaces. Specify a tag '
+      'if you want Cloud Build to build using a Dockerfile '
+      'instead of a build config file. If you specify a tag in this '
+      'command, your source must include a Dockerfile. For instructions '
+      'on building using a Dockerfile see '
+      'https://cloud.google.com/cloud-build/docs/quickstart-build.')
+  build_config.add_argument(
+      '--config',
+      default='cloudbuild.yaml',  # By default, find this in the current dir
+      help='The YAML or JSON file to use as the build configuration file.')
+  build_config.add_argument(
+      '--pack',
+      type=arg_parsers.ArgDict(spec={
+          'image': str,
+          'builder': str,
+          'env': str
+      }),
+      action='append',
+      help='Uses CNCF [buildpack](https://buildpacks.io/) to create image.  '
+      'The "image" key/value must be provided.  The image name must be in the '
+      'gcr.io/*, *.gcr.io, or pkg.dev namespaces. By default '
+      'gcr.io/buildpacks/builder will be used. To specify your own builder '
+      'image use the optional "builder" key/value argument.  To pass '
+      'environment variables to the builder use the optional "env" key/value '
+      'argument where value is a list of key values using '
+      '[escaping](https://cloud.google.com/sdk/gcloud/reference/topic/escaping) '
+      'if necessary.'
+  )
+
+
 def GetMachineType(machine_type_flag):
   """Return a machine type."""
   return _machine_type_flag_map.GetEnumForChoice(machine_type_flag)
