@@ -29,6 +29,7 @@ from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.compute import completers as compute_completers
 from googlecloudsdk.command_lib.compute import flags
 from googlecloudsdk.command_lib.compute import scope as compute_scope
+from googlecloudsdk.command_lib.compute.instance_groups.managed import flags as mig_flags
 from googlecloudsdk.command_lib.util import completers
 import six
 
@@ -291,6 +292,7 @@ _LIST_INSTANCES_FORMAT_BETA = """\
               instanceStatus:label=STATUS,
               instanceHealth[0].detailedHealthState:label=HEALTH_STATE,
               currentAction:label=ACTION,
+              preservedState():label=PRESERVED_STATE,
               version.instanceTemplate.basename():label=INSTANCE_TEMPLATE,
               version.name:label=VERSION_NAME,
               lastAttempt.errors.errors.map().format(
@@ -656,6 +658,7 @@ def AddCreateInstancesFlags(parser, add_stateful_args=True):
 
 
 def AddMigStatefulUpdateInstanceFlag(parser):
+  """Add flags for applying updates on PIC change."""
   parser.add_argument(
       '--update-instance',
       default=True,
@@ -672,6 +675,13 @@ def AddMigStatefulUpdateInstanceFlag(parser):
           for the disk. Similarly if you have attached a new disk or changed its
           definition, with this flag the MIG immediately refreshes the instance
           with the new config.""")
+  parser.add_argument(
+      '--instance-update-minimal-action',
+      choices=mig_flags.INSTANCE_ACTION_CHOICES,
+      default='none',
+      help="""
+          Perform at least this action on the instance while updating, if
+          `--update-instance` is set to `true`.""")
 
 
 def ValidateMigStatefulFlagsForInstanceConfigs(args,
@@ -874,7 +884,7 @@ def ValidateMigInstanceRedistributionTypeFlag(instance_redistribution_type,
             'managed instance groups only.'))
 
 
-DISTRIBUTION_POLICY_TARGET_SHAPES = ['EVEN', 'ANY']
+DISTRIBUTION_POLICY_TARGET_SHAPES = ['EVEN', 'ANY', 'BALANCED']
 
 
 def AddMigDistributionPolicyTargetShapeFlag(parser):
@@ -892,12 +902,17 @@ def AddMigDistributionPolicyTargetShapeFlag(parser):
 
       The following target shapes are available:
 
-       * EVEN - managed instance group will create and delete instances
-         in a manner preserving or converging to even distribution.
+       * EVEN - The managed instance group creates the same number of managed
+         instances in each zone without consideration for resource availability.
 
-       * ANY - managed instance group will create instances based on present
-         capacity constraints and will not attempt to converge to even
-         distribution.
+       * ANY - The managed instance group creates managed instances in zones
+         that have available resources - such as specialized hardware - and will
+         not attempt to converge to even distribution. All VMs might end up in a
+         single zone.
+
+       * BALANCED - The managed instance group creates managed instances in
+         zones as evenly as possible given availability of resources in each
+         zone, such as availability of specialized hardware.
       """)
 
 
