@@ -41,16 +41,18 @@ def _CommonArgs(parser):
       'Google Cloud Storage. If the source is a local directory, this '
       'command skips the files specified in the `--ignore-file`. If '
       '`--ignore-file` is not specified, use`.gcloudignore` file. If a '
-      '`.gitignore` file is present in the local source directory, gcloud '
-      'will use a Git-compatible `.gcloudignore` file that respects your '
-      '.gitignored files. The global `.gitignore` is not respected. For more '
-      'information on `.gcloudignore`, see `gcloud topic gcloudignore`.',
+      '`.gcloudignore` file is absent and a `.gitignore` file is present in '
+      'the local source directory, gcloud will use a generated Git-compatible '
+      '`.gcloudignore` file that respects your .gitignored files. The global '
+      '`.gitignore` is not respected. For more information on `.gcloudignore`, '
+      'see `gcloud topic gcloudignore`.',
   )
   source.add_argument(
       '--no-source',
       action='store_true',
       help='Specify that no source should be uploaded with this build.')
 
+  flags.AddRegionFlag(parser)
   flags.AddGcsSourceStagingDirFlag(parser)
   flags.AddGcsLogDirFlag(parser)
   flags.AddTimeoutFlag(parser)
@@ -135,6 +137,7 @@ class Submit(base.CreateCommand):
     Raises:
       FailedBuildException: If the build is completed and not 'SUCCESS'.
     """
+    build_region = args.region
 
     messages = cloudbuild_util.GetMessagesModule()
 
@@ -145,8 +148,12 @@ class Submit(base.CreateCommand):
         args.gcs_source_staging_dir, args.ignore_file, args.gcs_log_dir,
         args.machine_type, args.disk_size)
 
+    build_region = submit_util.DetermineBuildRegion(build_config, build_region)
+
     # Start the build.
-    return submit_util.Build(messages, args.async_, build_config)
+    build, _ = submit_util.Build(
+        messages, args.async_, build_config, build_region=build_region)
+    return build
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
@@ -192,6 +199,7 @@ class SubmitAlpha(SubmitBeta):
     Raises:
       FailedBuildException: If the build is completed and not 'SUCCESS'.
     """
+    build_region = args.region
 
     messages = cloudbuild_util.GetMessagesModule()
 
@@ -202,5 +210,9 @@ class SubmitAlpha(SubmitBeta):
         args.gcs_source_staging_dir, args.ignore_file, args.gcs_log_dir,
         args.machine_type, args.disk_size, args.pack)
 
+    build_region = submit_util.DetermineBuildRegion(build_config, build_region)
+
     # Start the build.
-    return submit_util.Build(messages, args.async_, build_config)
+    build, _ = submit_util.Build(
+        messages, args.async_, build_config, build_region=build_region)
+    return build
