@@ -41,6 +41,8 @@ _OUTPUT_FILTER = ['[Daisy', '[import-', 'starting build', '  import', 'ERROR']
 class Import(base.CreateCommand):
   """Import an instance into Google Compute Engine from OVF."""
 
+  _OS_CHOICES = os_choices.OS_CHOICES_INSTANCE_IMPORT_GA
+
   @classmethod
   def Args(cls, parser):
     instances_flags.AddCanIpForwardArgs(parser)
@@ -53,7 +55,7 @@ class Import(base.CreateCommand):
     instances_flags.AddDeletionProtectionFlag(parser)
     instances_flags.AddNetworkTierArgs(parser, instance=True)
     labels_util.AddCreateLabelsFlags(parser)
-    daisy_utils.AddCommonDaisyArgs(parser, add_log_location=False)
+    daisy_utils.AddCommonDaisyArgs(parser)
     daisy_utils.AddExtraCommonDaisyArgs(parser)
 
     instances_flags.INSTANCES_ARG_FOR_IMPORT.AddArgument(
@@ -64,7 +66,7 @@ class Import(base.CreateCommand):
     parser.add_argument(
         '--os',
         required=False,
-        choices=sorted(os_choices.OS_CHOICES_INSTANCE_IMPORT_BETA),
+        choices=sorted(cls._OS_CHOICES),
         help='Specifies the OS of the image being imported.')
 
     parser.add_argument(
@@ -175,6 +177,8 @@ class Import(base.CreateCommand):
 class ImportBeta(Import):
   """Import an instance into Google Compute Engine from OVF."""
 
+  _OS_CHOICES = os_choices.OS_CHOICES_INSTANCE_IMPORT_BETA
+
   @classmethod
   def Args(cls, parser):
     super(ImportBeta, cls).Args(parser)
@@ -195,6 +199,7 @@ Import.detailed_help = {
         *  Translate the boot disk to make it bootable in Google Compute Engine.
         *  Create a VM instance using OVF metadata and imported disks and boot it.
 
+        OVF import tool requires Cloud Build to be enabled. See [](https://cloud.google.com/compute/docs/import/import-ovf-files#enable-cloud-build)
         Virtual machine instances, images and disks in Compute engine and files
         stored on Cloud Storage incur charges. See [](https://cloud.google.com/compute/docs/images/importing-virtual-disks#resource_cleanup).
         """,
