@@ -278,7 +278,7 @@ class Update(base.UpdateCommand):
     flags.AddDailyMaintenanceWindowFlag(group, add_unset_text=True)
     flags.AddRecurringMaintenanceWindowFlags(group, is_update=True)
     flags.AddResourceUsageExportFlags(group, is_update=True)
-    flags.AddReleaseChannelFlag(group, is_update=True, hidden=True)
+    flags.AddReleaseChannelFlag(group, is_update=True, hidden=False)
     flags.AddWorkloadIdentityFlags(group)
     flags.AddWorkloadIdentityUpdateFlags(group)
     flags.AddDatabaseEncryptionFlag(group)
@@ -584,7 +584,7 @@ class UpdateBeta(Update):
     flags.AddResourceUsageExportFlags(group, is_update=True)
     flags.AddIstioConfigFlag(parser)
     flags.AddEnableIntraNodeVisibilityFlag(group)
-    flags.AddWorkloadIdentityFlags(group, use_workload_pool=False)
+    flags.AddWorkloadIdentityFlags(group, use_identity_provider=True)
     flags.AddWorkloadIdentityUpdateFlags(group)
     flags.AddDatabaseEncryptionFlag(group)
     flags.AddDisableDatabaseEncryptionFlag(group)
@@ -595,6 +595,7 @@ class UpdateBeta(Update):
     flags.AddEnableGvnicFlag(group)
     flags.AddDisableDefaultSnatFlag(group, for_cluster_create=False)
     flags.AddNotificationConfigFlag(group, hidden=True)
+    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1beta1', group, hidden=True)
 
   def ParseUpdateOptions(self, args, locations):
     flags.ValidateNotificationConfigFlag(args)
@@ -638,7 +639,7 @@ class UpdateBeta(Update):
 
     # Top-level update options are automatically forced to be
     # mutually-exclusive, so we don't need special handling for these two.
-    opts.identity_namespace = args.identity_namespace
+    opts.identity_provider = args.identity_provider
     opts.enable_shielded_nodes = args.enable_shielded_nodes
     opts.enable_tpu = args.enable_tpu
     opts.tpu_ipv4_cidr = args.tpu_ipv4_cidr
@@ -647,6 +648,7 @@ class UpdateBeta(Update):
     opts.enable_gvnic = args.enable_gvnic
     opts.disable_default_snat = args.disable_default_snat
     opts.notification_config = args.notification_config
+    opts.private_ipv6_google_access_type = args.private_ipv6_google_access_type
 
     return opts
 
@@ -692,7 +694,7 @@ class UpdateAlpha(Update):
     flags.AddIstioConfigFlag(parser)
     flags.AddCloudRunConfigFlag(parser)
     flags.AddEnableIntraNodeVisibilityFlag(group)
-    flags.AddWorkloadIdentityFlags(group, use_workload_pool=False)
+    flags.AddWorkloadIdentityFlags(group, use_identity_provider=True)
     flags.AddWorkloadIdentityUpdateFlags(group)
     flags.AddDisableDefaultSnatFlag(group, for_cluster_create=False)
     flags.AddDatabaseEncryptionFlag(group)
@@ -704,6 +706,7 @@ class UpdateAlpha(Update):
     flags.AddMasterGlobalAccessFlag(group)
     flags.AddEnableGvnicFlag(group)
     flags.AddNotificationConfigFlag(group, hidden=True)
+    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1alpha1', group, hidden=True)
 
   def ParseUpdateOptions(self, args, locations):
     flags.ValidateNotificationConfigFlag(args)
@@ -720,7 +723,8 @@ class UpdateAlpha(Update):
     opts.enable_network_egress_metering = args.enable_network_egress_metering
     opts.enable_resource_consumption_metering = args.enable_resource_consumption_metering
     flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
-    flags.ValidateCloudRunConfigUpdateArgs(args.cloud_run_config, args.disable_addons)
+    flags.ValidateCloudRunConfigUpdateArgs(args.cloud_run_config,
+                                           args.disable_addons)
     if args.disable_addons and api_adapter.NODELOCALDNS in args.disable_addons:
       # NodeLocalDNS is being enabled or disabled
       console_io.PromptContinue(
@@ -752,12 +756,13 @@ class UpdateAlpha(Update):
 
     # Top-level update options are automatically forced to be
     # mutually-exclusive, so we don't need special handling for these two.
-    opts.identity_namespace = args.identity_namespace
+    opts.identity_provider = args.identity_provider
     opts.enable_shielded_nodes = args.enable_shielded_nodes
     opts.disable_default_snat = args.disable_default_snat
     opts.enable_cost_management = args.enable_cost_management
     opts.enable_master_global_access = args.enable_master_global_access
     opts.enable_gvnic = args.enable_gvnic
     opts.notification_config = args.notification_config
+    opts.private_ipv6_google_access_type = args.private_ipv6_google_access_type
 
     return opts
