@@ -56,6 +56,7 @@ class Create(base.Command):
     # Flags specific to connecting to a cluster
     cluster_group = serverless_flags.GetClusterArgGroup(parser)
     flags.AddBrokerFlag(cluster_group)
+    flags.AddFiltersFlags(cluster_group)
 
     # Flags not specific to any platform
     flags.AddEventTypeFlagArg(parser)
@@ -80,7 +81,7 @@ class Create(base.Command):
 
   def Run(self, args):
     conn_context = connection_context.GetConnectionContext(
-        args, product=serverless_flags.Product.EVENTS)
+        args, serverless_flags.Product.EVENTS, self.ReleaseTrack())
 
     trigger_ref = args.CONCEPTS.trigger.Parse()
     namespace_ref = trigger_ref.Parent()
@@ -119,8 +120,8 @@ class Create(base.Command):
                 'matching this event type.'.format(trigger_obj.name))
           # If the trigger has the right attributes, check if there's already
           # a source that matches the attributes as well.
-          source_ref = util.GetSourceRef(
-              source_obj.name, source_obj.namespace, event_type.crd)
+          source_ref = util.GetSourceRef(source_obj.name, source_obj.namespace,
+                                         event_type.crd, client.IsCluster())
           if client.GetSource(source_ref, event_type.crd) is not None:
             raise exceptions.TriggerCreationError(
                 'Trigger [{}] already exists.'.format(trigger_obj.name))
@@ -134,7 +135,7 @@ class Create(base.Command):
           trigger_obj = client.CreateTrigger(
               trigger_ref, source_obj,
               event_type if args.custom_type else event_type.type,
-              args.target_service, args.broker)
+              args.trigger_filters, args.target_service, args.broker)
         if not args.custom_type:
           client.CreateSource(source_obj, event_type.crd, trigger_obj,
                               namespace_ref, args.broker, parameters)
