@@ -62,7 +62,7 @@ class Delete(base.Command):
   def Run(self, args):
     """Executes when the user runs the delete command."""
     conn_context = connection_context.GetConnectionContext(
-        args, product=serverless_flags.Product.EVENTS)
+        args, serverless_flags.Product.EVENTS, self.ReleaseTrack())
 
     trigger_ref = args.CONCEPTS.trigger.Parse()
     console_io.PromptContinue(
@@ -77,7 +77,7 @@ class Delete(base.Command):
         if trigger_obj is not None:
           source_crds = client.ListSourceCustomResourceDefinitions()
           source_ref, source_crd = util.GetSourceRefAndCrdForTrigger(
-              trigger_obj, source_crds)
+              trigger_obj, source_crds, client.IsCluster())
           if source_ref and source_crd:
             # Delete the source before the trigger because we need the trigger
             # to exist to be able to find the source. Otherwise, we could end up
